{% extends 'base_navbar.html' %}
{% block content %}
<main class="container">
    <div class="bg-light p-5 rounded">
        <h1>Hello Example nash</h1>
        <p class="lead">This example
            of your browser’s viewport.</p>
        <a class="btn btn-lg btn-primary" href="../components/navbar/" role="button">View navbar docs &raquo;</a>
    </div>
</main>
{% endblock %}
