#-*- coding:utf-8 -*-
# Copyright (c) 2021, 2022 Narotechnology, nash@narotechnology.com
# SPDX-License-Identifier: LicenseRef-Narotechnology-Proprietary

"""

"""
import time

print('<-', __name__)


__title__ = "naro-laser"
__summary__ = "Laser Sensor Backend App"
__version__ = '0.1.2'
__build_date__ = '2022.01.11'
__uri__ = "https://test.pypi.org/"

'''
    Korean not allowed currently, 21.12
    https://github.com/pypa/warehouse/blob/64ca42e42d5613c8339b3ec5e1cb7765c6b23083/warehouse/__about__.py
'''

'''
Release History 

0.1.2, 22.01.11
    
0.1.2rc3, 22.01.11
    repair
    
0.1.2rc2, 22.01.11
    add mini web server
    add lte-m1 control    
    
0.1.1, 21.12.23
    auto start using crontab
    change execution mode to 'sudo pipenv...'
    
0.1.1rc2, 21.12.22
    add color led neopixel control routine
        sudo required
    change thingsboard url:
        nash.wo.tc -> nash.mywire.org

'''