<!doctype html>
<html lang="en">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="for laser sensor, 2021, Naro">
    <meta name="author" content="nash403">
    <title>{{s_hostname}}</title>
    <link href="/static/css/bootstrap.min.css" rel="stylesheet">
    <style>
      .bd-placeholder-img {
        font-size: 1.125rem;
        text-anchor: middle;
        -webkit-user-select: none;
        -moz-user-select: none;
        user-select: none;
      }

      @media (min-width: 768px) {
        .bd-placeholder-img-lg {
          font-size: 3.5rem;
        }
      }




    </style>
    <link href="/static/css/navbar-top-fixed.css" rel="stylesheet">
</head>

<body>
<nav class="navbar navbar-expand-md navbar-dark fixed-top bg-dark">
    <div class="container-fluid">
        <a class="navbar-brand" href="#">Menu</a>
        <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarCollapse"
                aria-controls="navbarCollapse" aria-expanded="false" aria-label="Toggle navigation">
            <span class="navbar-toggler-icon"></span>
        </button>
        <div class="collapse navbar-collapse" id="navbarCollapse">
            <ul class="navbar-nav me-auto mb-2 mb-md-0">
                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="{{ url_for('navbar.index') }}">Home</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="{{ url_for('navbar.config') }}">Config</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="{{ url_for('navbar.status') }}">Status</a>
                </li>

                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="{{ url_for('navbar.chart') }}">Chart</a>
                </li>
                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="{{ url_for('navbar.hello') }}">Hello</a>
                </li>

                <!-- 아래 항목은 개발용이다-->
                <li class="nav-item">
                    <a class="nav-link" aria-current="page" href="{{ url_for('navbar.config_test') }}">ConfigTesting</a>
                </li>
                <!-- 위 항목은 개발용이다-->


            </ul>
        </div>
    </div>
</nav>

<section class="content">
    {% block content %}
    {% endblock %}
</section>

<script src="/static/js/bootstrap.bundle.min.js"></script>
</body>
</html>
