{% extends 'base_navbar.html' %}
{% block content %}
<main class="container">
    <div class="bg-light p-5 rounded">
        <h1>Home</h1>
        <p class="lead">Laser sensor</p>
    </div>
</main>
{% endblock %}
